@@ -1,9 +1,6 @@
 import json
 import logging
-from threading import Thread
-from queue import Queue, Empty, Full
-import itertools
-from time import sleep
+
 import serial
 
 from .publishers.httppublisher import HttpPublisher
@@ -37,36 +34,18 @@ class HtDataClient:
         except ConnectionRefusedError as e:
             self.logger.warn(e.strerror)
 
-    def run(self, work_queue):
+    def run(self):
         self.logger.debug('Hit reader is running')
         try:
             with serial.serial_for_url(self.device_path) as io_dev:
                 for hit in SourceReader(io_dev):
-
                     self.logger.info(json.dumps(hit, sort_keys=True))
-                    work_queue.put(hit)
-                    #self.publish(hit)
+                    self.publish(hit)
         except serial.serialutil.SerialException as e:
             self.logger.debug(e)
         except KeyboardInterrupt:
             pass
 
-def publisher(work_queue):
-    publish_url = 'http://localhost/games/hit'
-    if not publish_url:
-        return
-    while True:
-        data = work_queue.get()
-        publisher = HttpPublisher(publish_url)
-        try:
-            response = publisher.publish(data)
-            print(response)
-            #self.logger.info(response)
-        except ConnectionRefusedError as e:
-            print(e.strerror)
-            #self.logger.warn(e.strerror)
-
-
 def runner():
     import argparse
     parser = argparse.ArgumentParser(description='View and publish incoming hits to a target url')
@@ -79,16 +58,4 @@ def runner():
     args = parser.parse_args()
 
     reader = HtDataClient(args.source_path, args.publish_url, args.log_level)
-    work_queue = Queue()
-
-    threads = [Thread(target=publisher, args=(work_queue,)) for i in range(2)]
-    threads.insert(0,Thread(target=reader.run, args=(work_queue,)))
-
-    #for t in threads:
-    #    t.start()
-
-print('we run')
-    #for t in threads:
-    #    t.join()
-    #reader.run()
-
+    reader.run()
